function [data,outromtag] = mphreduction(model,varargin)
% MPHREDUCTION Return reduced order state-space matrices for a model
%
% data = MPHREDUCTION(model, ...) calculates reduced order state-space
% matrices for a model based on a time dependent model and a training
% study. These studies may already exist in the model or new studies may
% be added by MPHREDUCTION.
% MPHREDUCTION will by default delete all added studies upon completion. The
% property 'keepfeature' may be used to change that, which makes it
% possible to work further on already added studies since MPHREDUCTION does
% not support all settings that are possible for model reduction.
%
%   Valid property/value pairs include:
%   Property            Value/{Default}     Description
%   -----------------------------------------------------------------------
%   out                 'all'               Names of output matrices
%   unreducedstudy      char                Unreduced study tag
%   unreducedstudystep  char                Unreduced study step tag
%   unreducedsteps      1                   Unreduced time or frequency step
%   trainingstudy       char                Training study tag
%   trainingstudystep   char                Training study step tag
%   trainingstudyneigs  {6}                 Number of eigenvalues in training study
%   trainingstudyeigsnear  char | '1[Hz]'   Search for eigenvalues near
%   reductionstudy      char                Model reduction study tag
%   reductionsol        char                Model reduction solution tag
%   reductionmodalsol   char                Modal solver tag
%   eigmethod           {'default'} |       Method for eigenvalues
%                       'region'
%   appneigs            integer             Approximate number of eigenvalues
%   maxneigs            integer             Maximum number of eigenvalues
%   eigsrange           []                  Eigenvalues in range
%   controls            cell array          Model control inputs parameters (u)
%   controlvals         vector              Control input values
%   output              cell array          Outputs (y)
%   return              {'struct'} | 'ss'   Return type
%   keepfeature         'on' | {'off'}      Keep the added features in the model
%   clean           'on' | {'off'}          Clean previously added features
%                                           from the model
%
%   Example:
%   Calculate a reduced order state space system using the existing
%   unreduced study 'std1' and existing eigenvalue study 'std2'. Use the
%   control variable (parameter) 'Qin' and the output (probe)
%   'comp1.intop1(T)'
%   MR = mphreduction(model, ...
%     'out', {'MA' 'MB' 'A' 'B' 'C' 'D'}, ...
%     'controls', {'Qin'}, ...
%     'controlvals', [1], ...
%     'output', 'comp1.intop1(T)', ...
%     'unreducedstudy', 'std1', ...
%     'trainingstudy', 'std2')
%
%   See also: mphstate
%
% out is a cell array with the names of matrices to extract. These include
% Mc, MA, MB, Null, D, C, ud, x0, A, B as well as
% Kr, Dr, Dra, Er, Pm, L, Br, Cr, Y0, F, Brdot, Brdotdot, U0, Udot0, B0r,
% B0rdot, Kud.
%
% eigsrange is a vector with two element (possibly complex) that contains
% the smallest and largest eigenvalue to search for.
%
% Return type 'ss' requires that the Control System Toolbox is installed.

%   Copyright 2010-2017 COMSOL
